@@ -1,7 +1,8 @@
+{-# LANGUAGE PackageImports #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.Generics.Sum
--- Copyright   :  (C) 2019 Csongor Kiss
+-- Copyright   :  (C) 2020 Csongor Kiss
 -- License     :  BSD3
 -- Maintainer  :  Csongor Kiss <kiss.csongor.kiss@gmail.com>
 -- Stability   :  experimental
@@ -23,7 +24,7 @@ module Data.Generics.Sum
   , module Data.Generics.Sum.Typed
   ) where
 
-import Data.Generics.Sum.Any
-import Data.Generics.Sum.Constructors
-import Data.Generics.Sum.Subtype
-import Data.Generics.Sum.Typed
+import "this" Data.Generics.Sum.Any
+import "this" Data.Generics.Sum.Constructors
+import "this" Data.Generics.Sum.Subtype
+import "this" Data.Generics.Sum.Typed
